from enum import Enum

class ConfigEnum(Enum):
    REDIS          = 'redis'
    PROCESSING     = 'processing'
    LIMITS         = 'limits'
    SENSORS        = 'sensors'
    INTEGRATION    = 'integration'
    JAMMER         = 'jammer'
    JAMMING_SIGNAL = 'jamming_signal'
    DENSITY        = 'density'
    PROBABILITY    = 'probability'
    APP_DATA       = 'app_data'
    DEVICES        = 'devices'
    CONFIG         = 'config'
    RMS            = 'rms'
    DATA           = 'data'
    IMAGE          = 'image'
    TIME           = 'time'
    REDIS_ACTIVE   = 'redis_connected'
    REDIS_UPDATED  = 'redis_updated'
    ALL_DATA       = 'all_data'


class ConfigStrings(Enum):
    LAT           = 'lat'
    LON           = 'lon'
    HGT           = 'h'
    POWER         = 'P'
    MIN           = 'min'
    MAX           = 'max'
    STEPS         = 'n_steps'
    INTEGRATE_OUT = 'integrate_out'
    MINIMA        = 'minima'
    MAXIMA        = 'maxima'


class RequestEnums(Enum):
    INDEXES    = 'indexes'
    FLIP       = 'flip'
    REDIS      = 'redis'
    CONFIG     = 'config'
    DIMENSIONS = 'dimensions'


class RedisServerEnum(Enum):
    CONFIGURATION = 'configuration'
    RESULTS       = 'results'


class AppTabs(Enum):
    MAIN    = 'tab_main_vis'
    SPEC    = 'tab_spec_vis'
    RMS     = 'tab_rms'
    SENSORS = 'tab_sensors'
    DEVICES = 'tab_devices'
    CONFIG  = 'tab_config'


class TabsEnum(Enum):
    NUMBER  = 0
    GRAPH   = 1
    HEAT    = 2
    SPACE   = 3
    UNKNOWN = 4


class RedisEnum(Enum):
    IP        = (0, 'ip')
    PORT      = (1, 'port')
    CONNECTED = (2, 'connected')

    def __new__(cls, value, string_value):
        obj = object.__new__(cls)
        obj._value_ = value
        obj.string = string_value
        return obj

    def __str__(self):
        return self.string

    @classmethod
    def get_name(cls):
        return "Redis"


class LimitsEnum(Enum):
    #                      Id |     String name      |    Config enum    | Unit | Can be int in Sliders | Priority (highest number is the highest priority)
    LATITUDE             = (0, 'Latitude',            ConfigStrings.LAT,   'deg',  False,                 2)
    LONGITUDE            = (1, 'Longitude',           ConfigStrings.LON,   'deg',  False,                 1)
    HEIGHT               = (2, 'Height',              ConfigStrings.HGT,   'm'  ,  True ,                 3)
    POWER                = (3, 'Power',               ConfigStrings.POWER, 'dBm',  True ,                 4)
    GRAPH_PROBAB_DENSITY = (4, "Probability Density", None,                '-',    False,                 0) # Limits for Probability Density - 2d graph in bottom right corner of Main Tab

    def __new__(cls, value, string_value, config_value, unit, can_be_int, priority):
        obj = object.__new__(cls)
        obj._value_    = value
        obj.string     = string_value
        obj.config     = config_value
        obj.unit       = unit
        obj.can_be_int = can_be_int
        obj.priority   = priority
        return obj

    def __str__(self):
        return self.string

    @classmethod
    def get_enum_by_string(cls, string_value):
        for member in cls:
            if member.string == string_value:
                return member
        raise ValueError(f"No enum member with string value '{string_value}'")

    @classmethod
    def get_enum_by_id(cls, value):
        for member in cls:
            if member._value_ == value:
                return member
        raise ValueError(f"No enum member with id value '{value}'")

    @classmethod
    def get_name(cls):
        return "Limits"



class ProcessingEnum(Enum):
    RECORD  = (0, "record", "Record")
    PATH    = (1, "record_path", "Record Path")
    REPLAY  = (2, "replay", "Replay")
    START   = (3, "replay_start", "Replay Start")
    END     = (4, "replay_end", "Replay Stop")
    SPEED   = (5, "replay_speed", "Replay Speed")
    MODE    = (6, "integration_mode", "Integration Mode")
    M_VALUE = (7, "integration_mode_value", "Integration Mode Value")
    UNDUL   = (8, "undulation", "Undulation [m]")
    TIME_D  = (9, "time_degradation", "Time Degradation [%/s]")

    def __new__(cls, value, string_value, label_value):
        obj = object.__new__(cls)
        obj._value_ = value
        obj.string = string_value
        obj.label = label_value
        return obj

    def __str__(self):
        return self.string

    @classmethod
    def get_enum_by_string(cls, string_value):
        for member in cls:
            if member.string == string_value:
                return member
        raise ValueError(f"No enum member with string value '{string_value}'")

    @classmethod
    def get_enum_by_id(cls, value):
        for member in cls:
            if member._value_ == value:
                return member
        raise ValueError(f"No enum member with id value '{value}'")

    @classmethod
    def get_name(cls):
        return "Processing"



class FlipEnum(Enum):
    VERTICAL   = 'vertical'
    HORIZONTAL = 'horizontal'


