import sys
sys.path.append('../../Visualiser')

import unittest
import math
import numpy as np

from appEnums      import LimitsEnum
from utils         import fillWithZeros, fillWithZeros3D, getJammingIndexes
from views.devices import display_delete_rows

class tests_fillWithZeros(unittest.TestCase):

    def test_fillWithZeros_One(self):
        ''' Test case from method description. '''
        original_data    = [1,1,1,1,1,1,1,1,1]
        x_steps, y_steps = 5, 5
        index_x_min, index_x_max, index_y_min, index_y_max = 1, 3, 1, 3
        expected_result = np.array([0,0,0,0,0,
                                    0,1,1,1,0,
                                    0,1,1,1,0,
                                    0,1,1,1,0,
                                    0,0,0,0,0
                                    ])

        result = fillWithZeros(original_data, x_steps, y_steps, index_x_min, index_x_max, index_y_min, index_y_max)
        self.assertTrue(np.array_equal(result, expected_result))


    def test_fillWithZeros_Two(self):
        ''' Empty input array will create array of original steps filled with zeros. '''
        original_data = []
        x_steps, y_steps = 5, 5
        index_x_min, index_x_max, index_y_min, index_y_max = 1, 3, 1, 3
        expected_result = np.zeros((x_steps * y_steps,))
        result = fillWithZeros(original_data, x_steps, y_steps, index_x_min, index_x_max, index_y_min, index_y_max)
        self.assertTrue(np.array_equal(result, expected_result))


    def test_fillWithZeros3D_One(self):
        x_steps, y_steps, z_steps = 5, 5, 5
        original_data = np.array([ 0,  1,  2,  3,  4,  5,  6,  7,  8,
                                   9, 10, 11, 12, 13, 14, 15, 16, 17,
                                  18, 19, 20, 21, 22, 23, 24, 25, 26])
        expected_result = np.array([  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
                                      0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  1,  2,  0,  0,
                                      3,  4,  5,  0,  0,  6,  7,  8,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
                                      0,  0,  9, 10, 11,  0,  0, 12, 13, 14,  0,  0, 15, 16, 17,  0,  0,  0,
                                      0,  0,  0,  0,  0,  0,  0,  0,  0, 18, 19, 20,  0,  0, 21, 22, 23,  0,
                                      0, 24, 25, 26,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
                                      0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0])
        result = fillWithZeros3D(original_data, x_steps, y_steps, z_steps, 1, 3, 1, 3, 1, 3)
        self.assertTrue(np.array_equal(result, expected_result))


class tests_getJammingIndexes(unittest.TestCase):

    def test_getJammingIndexes_One(self):
        fusion_config_lite = {"limits":
            {
                "lon": {"min": 0.23990334370132863, "max": 0.2590645194439135, "n_steps": 100 },
                "lat": {"min": 0.8650072449046965,  "max": 0.8835591454671903, "n_steps": 100 },
                "h":   {"min": 0,                   "max": 5000,               "n_steps": 20  },
                "P":   {"min": -100,                "max": 100,                "n_steps": 100 }
            },
            "integration": {"jammer": { "density": [ {
                            "lon": {"min": 0.2399827721492203, "max": 0.2590068609959585, "integrate_out": False },
                            "lat": {"min": 0.8649851772883898, "max": 0.8834856673595296, "integrate_out": False },
                            "h":   {"min": 0,                  "max": 5000,               "integrate_out": True },
                            "P":   {"min": -50,                "max": 50,                 "integrate_out": True }
                        }, {
                            "lon": {"min": -1E+30, "max": 1E+30, "integrate_out": True },
                            "lat": {"min": -1E+30, "max": 1E+30, "integrate_out": True },
                            "h":   {"min": -1E+30, "max": 1E+30, "integrate_out": True },
                            "P":   {"min": -1E+30, "max": 1E+30, "integrate_out": False }
                        }],},}}

        first_limit   = LimitsEnum.HEIGHT
        second_limit  = LimitsEnum.POWER
        density_index = 0
        expected_result = (0,19,24,74)
        
        result = getJammingIndexes(fusion_config_lite, first_limit, second_limit, density_index)
        self.assertTrue(np.array_equal(result, expected_result))


    def test_getJammingIndexes_Two(self):
        fusion_config_lite = {"limits":
            {
                "lon": {"min": 0.23990334370132863, "max": 0.2590645194439135, "n_steps": 100 },
                "lat": {"min": 0.8650072449046965,  "max": 0.8835591454671903, "n_steps": 100 },
                "h":   {"min": 0,                   "max": 5000,               "n_steps": 20  },
                "P":   {"min": -100,                "max": 100,                "n_steps": 100 }
            },
            "integration": {"jammer": { "density": [ {
                            "lon": {"min": 0.2399827721492203, "max": 0.2590068609959585, "integrate_out": False },
                            "lat": {"min": 0.8649851772883898, "max": 0.8834856673595296, "integrate_out": False },
                            "h":   {"min": 0,                  "max": 2500,               "integrate_out": True },
                            "P":   {"min": -0,                 "max": 100,                "integrate_out": True }
                        }, {
                            "lon": {"min": -1E+30, "max": 1E+30, "integrate_out": True },
                            "lat": {"min": -1E+30, "max": 1E+30, "integrate_out": True },
                            "h":   {"min": -1E+30, "max": 1E+30, "integrate_out": True },
                            "P":   {"min": -1E+30, "max": 1E+30, "integrate_out": False }
                        }],},}}

        first_limit   = LimitsEnum.HEIGHT
        second_limit  = LimitsEnum.POWER
        density_index = 0
        expected_result = (0,9,50,99)
        
        result = getJammingIndexes(fusion_config_lite, first_limit, second_limit, density_index)
        self.assertTrue(np.array_equal(result, expected_result))

    def test_getJammingIndexes_Three(self):
        fusion_config_lite = {"limits":
            {
                "lon": {"min": 13.74544908516253*math.pi/180, "max": 14.843303585721097*math.pi/180, "n_steps": 100 },
                "lat": {"min": 49.56126438127829*math.pi/180, "max": 50.624209985455565*math.pi/180, "n_steps": 100 },
                "h":   {"min": 0,                   "max": 5000,               "n_steps": 20  },
                "P":   {"min": -100,                "max": 100,                "n_steps": 100 }
            },
            "integration": {"jammer": { "density": [ {
                            "lon": {"min": 13.75*math.pi/180,  "max": 14.61*math.pi/180,  "integrate_out": False },
                            "lat": {"min": 49.56*math.pi/180,  "max": 50.40*math.pi/180,  "integrate_out": False },
                            "h":   {"min": 0,                  "max": 2500,               "integrate_out": True },
                            "P":   {"min": -0,                 "max": 100,                "integrate_out": True }
                        }, {
                            "lon": {"min": -1E+30, "max": 1E+30, "integrate_out": True },
                            "lat": {"min": -1E+30, "max": 1E+30, "integrate_out": True },
                            "h":   {"min": -1E+30, "max": 1E+30, "integrate_out": True },
                            "P":   {"min": -1E+30, "max": 1E+30, "integrate_out": False }
                        }],},}}

        first_limit   = LimitsEnum.LATITUDE
        second_limit  = LimitsEnum.LONGITUDE
        density_index = 0
        expected_result = (0,78,0,78)
        
        result = getJammingIndexes(fusion_config_lite, first_limit, second_limit, density_index)
        self.assertTrue(np.array_equal(result, expected_result))



# -----------------------------------------------------------------------------
# view/devices.py
#
class tests_devices_display_delete_rows(unittest.TestCase):

    def test_devices_display_delete_rows_one(self):
        ''' Test of delete of one row - device not present in RMs Info Table. '''
        isRendering         = False
        selected_rows       = None
        rows_to_delete      = []
        devices_data        = [
            {
                "backup": None,
                "color": "red",
                "enabledInFusion": True,
                "hgt": 425.846144400537,
                "identifier": 0,
                "incoming": None,
                "lat": 50.124209985455565,
                "lon": 14.301380914837464,
                "mlat_system": None,
                "name": "Airplane 1",
                "probability": 0.7705128205128204,
                "redundancy": None,
                "rms_confirmed": None,
                "sensitivity": 0.7,
                "tileIndex": 5250,
                "timeJammingSince": None,
                "typ": "Airplane"
            },
            {
                "backup": None,
                "color": "red",
                "enabledInFusion": True,
                "hgt": None,
                "identifier": 1,
                "incoming": None,
                "lat": 50.0882512280772,
                "lon": 14.30135998486724,
                "mlat_system": "MLAT 3",
                "name": "Airplane 2",
                "probability": 0.9474358974358974,
                "redundancy": None,
                "rms_confirmed": None,
                "sensitivity": 0.7,
                "tileIndex": 4950,
                "timeJammingSince": None,
                "typ": "MLAT Antenna"
            },
            {
                "backup": "0",
                "color": "green",
                "enabledInFusion": True,
                "hgt": 425.846144400537,
                "identifier": 2,
                "incoming": None,
                "lat": 50.12420998545556,
                "lon": 14.245449085162532,
                "mlat_system": None,
                "name": "Radar 1",
                "probability": 0.7435897435897435,
                "redundancy": None,
                "rms_confirmed": None,
                "sensitivity": 0.7,
                "tileIndex": 5245,
                "timeJammingSince": None,
                "typ": "ADS-B System"
            },
            {
                "backup": "0",
                "color": "green",
                "enabledInFusion": True,
                "hgt": 425.846145702526,
                "identifier": 3,
                "incoming": "cpu",
                "lat": 50.0882512280772,
                "lon": 14.245470015132756,
                "mlat_system": None,
                "name": "MLAT 3",
                "probability": 1,
                "redundancy": None,
                "rms_confirmed": None,
                "sensitivity": "0.5",
                "tileIndex": 4945,
                "timeJammingSince": None,
                "typ": "MLAT System"
            },
            {
                "backup": None,
                "color": "green",
                "enabledInFusion": False,
                "hgt": 4000,
                "identifier": 4,
                "incoming": None,
                "lat": 49.74375,
                "lon": 15.338639,
                "mlat_system": None,
                "name": "Stred CR",
                "probability": None,
                "rms_confirmed": None,
                "sensitivity": 0.7,
                "tileIndex": None,
                "timeJammingSince": None,
                "typ": "Airplane"
            },
            {
                "backup": None,
                "color": "green",
                "enabledInFusion": False,
                "hgt": 4000,
                "identifier": 5,
                "incoming": None,
                "lat": 49.9,
                "lon": 15.9,
                "mlat_system": None,
                "name": "Random Marker",
                "probability": None,
                "rms_confirmed": None,
                "sensitivity": 0.7,
                "tileIndex": None,
                "timeJammingSince": None,
                "typ": "Vehicle"
            },
            {
                "backup": None,
                "color": "green",
                "enabledInFusion": False,
                "hgt": 4000,
                "identifier": 6,
                "incoming": None,
                "lat": 50.12,
                "lon": 14.15,
                "mlat_system": None,
                "name": "Praha",
                "probability": None,
                "rms_confirmed": None,
                "sensitivity": 0.7,
                "tileIndex": 5236,
                "timeJammingSince": None,
                "typ": "RADAR"
            },
            {
                "backup": None,
                "color": "green",
                "enabledInFusion": False,
                "hgt": 4000,
                "identifier": 7,
                "incoming": None,
                "lat": 50.22,
                "lon": 14.25,
                "mlat_system": None,
                "name": "Praha 2",
                "probability": None,
                "rms_confirmed": None,
                "sensitivity": 0.7,
                "tileIndex": 6145,
                "timeJammingSince": None,
                "typ": "ADS-B System"
            },
            {
                "backup": None,
                "color": "green",
                "enabledInFusion": False,
                "hgt": 4000,
                "identifier": 8,
                "incoming": None,
                "lat": 50.12,
                "lon": 14.05,
                "mlat_system": None,
                "name": "Praha 3",
                "probability": None,
                "rms_confirmed": None,
                "sensitivity": 0.7,
                "tileIndex": 5227,
                "timeJammingSince": None,
                "typ": "MLAT System"
            },
            {
                "backup": None,
                "color": "green",
                "enabledInFusion": False,
                "hgt": 4000,
                "identifier": 9,
                "incoming": None,
                "lat": 50.124209985455565,
                "lon": 14.301380914837464,
                "mlat_system": None,
                "name": "9_Airplane 1",
                "probability": None,
                "rms_confirmed": None,
                "sensitivity": 0.7,
                "tileIndex": 5250,
                "timeJammingSince": None,
                "typ": "Data Processing System"
            },
            {
                "backup": None,
                "color": "green",
                "enabledInFusion": False,
                "hgt": 4000,
                "identifier": 10,
                "incoming": None,
                "lat": 50.0882512280772,
                "lon": 14.30135998486724,
                "mlat_system": None,
                "name": "10_Airplane 2",
                "probability": None,
                "rms_confirmed": None,
                "sensitivity": 0.7,
                "tileIndex": 4950,
                "timeJammingSince": None,
                "typ": "Airplane"
            },
            {
                "backup": None,
                "color": "green",
                "enabledInFusion": False,
                "hgt": 4000,
                "identifier": 12,
                "incoming": None,
                "lat": 50.1,
                "lon": 14.28,
                "mlat_system": None,
                "name": "13_Airplane 1",
                "probability": None,
                "rms_confirmed": None,
                "sensitivity": 0.7,
                "tileIndex": 5048,
                "timeJammingSince": None,
                "typ": "Data Processing System"
            },
            {
                "backup": None,
                "color": "green",
                "enabledInFusion": False,
                "hgt": 4000,
                "identifier": 13,
                "incoming": None,
                "lat": 50.57113745662007,
                "lon": 13.837015281317054,
                "mlat_system": None,
                "name": "Top Left",
                "probability": None,
                "rms_confirmed": None,
                "sensitivity": 0.7,
                "tileIndex": 9508,
                "timeJammingSince": None,
                "typ": "Data Processing System"
            },
            {
                "backup": None,
                "color": "green",
                "enabledInFusion": False,
                "hgt": 4000,
                "identifier": 14,
                "incoming": None,
                "lat": 49.59554112809707,
                "lon": 14.787169519514498,
                "mlat_system": None,
                "name": "Bottom Right",
                "probability": None,
                "rms_confirmed": None,
                "sensitivity": 0.7,
                "tileIndex": 394,
                "timeJammingSince": None,
                "typ": "Data Processing System"
            },
            {
                "backup": None,
                "color": "green",
                "enabledInFusion": False,
                "hgt": 4000,
                "identifier": 15,
                "incoming": None,
                "lat": 49.49554112809707,
                "lon": 14.687169519514498,
                "mlat_system": None,
                "name": "16_Bottom Right",
                "probability": None,
                "rms_confirmed": None,
                "sensitivity": 0.7,
                "tileIndex": "Praha 3",
                "timeJammingSince": None,
                "typ": "MLAT Antenna"
            },
            {
                "backup": None,
                "color": "green",
                "enabledInFusion": True,
                "hgt": 4000,
                "identifier": 16,
                "incoming": None,
                "lat": 49,
                "lon": 14,
                "mlat_system": None,
                "name": "new onee",
                "probability": None,
                "rms_confirmed": None,
                "sensitivity": "0.5",
                "tileIndex": None,
                "timeJammingSince": None,
                "typ": "Airplane"
            },
            {
                "name": "second one",
                "typ": "RADAR",
                "color": "green",
                "lat": 49.6,
                "lon": 14.8,
                "hgt": 4000,
                "sensitivity": 0.3,
                "incoming": None,
                "backup": None,
                "enabledInFusion": False,
                "identifier": 17,
                "tileIndex": 396,
                "timeJammingSince": None,
                "probability": None,
                "rms_confirmed": None,
                "mlat_system": None
            }]
        devices_data_colors = [
            {
                "backup": None,
                "color": "red",
                "enabledInFusion": True,
                "hgt": 425.846144400537,
                "identifier": 0,
                "incoming": None,
                "lat": 50.124209985455565,
                "lon": 14.301380914837464,
                "mlat_system": None,
                "name": "Airplane 1",
                "probability": 0.7705128205128204,
                "redundancy": None,
                "rms_confirmed": "{'Letadlo-1': False, 'Letadlo-2': False, 'Letadlo-3': False, 'Letadlo-4': None, 'Letadlo-5': None}",
                "sensitivity": 0.7,
                "tileIndex": 5250,
                "timeJammingSince": "{'Letadlo-1': 35.0, 'Letadlo-2': 35.0, 'Letadlo-3': 35.0, 'Letadlo-4': None, 'Letadlo-5': None}",
                "typ": "Airplane"
            },
            {
                "backup": None,
                "color": "red",
                "enabledInFusion": True,
                "hgt": None,
                "identifier": 1,
                "incoming": None,
                "lat": 50.0882512280772,
                "lon": 14.30135998486724,
                "mlat_system": "MLAT 3",
                "name": "Airplane 2",
                "probability": 0.9474358974358974,
                "redundancy": None,
                "rms_confirmed": "{'MLAT-Ant-1': False}",
                "sensitivity": 0.7,
                "tileIndex": 4950,
                "timeJammingSince": "{'MLAT-Ant-1': 35.0}",
                "typ": "MLAT Antenna"
            },
            {
                "backup": "0",
                "color": "green",
                "enabledInFusion": True,
                "hgt": 425.846144400537,
                "identifier": 2,
                "incoming": None,
                "lat": 50.12420998545556,
                "lon": 14.245449085162532,
                "mlat_system": None,
                "name": "Radar 1",
                "probability": 0.7435897435897435,
                "redundancy": None,
                "rms_confirmed": "{'ADS-B-1': None, 'ADS-B-2': None, 'ADS-B-3': None}",
                "sensitivity": 0.7,
                "tileIndex": 5245,
                "timeJammingSince": "{'ADS-B-1': None, 'ADS-B-2': None, 'ADS-B-3': None}",
                "typ": "ADS-B System"
            },
            {
                "backup": "0",
                "color": "green",
                "enabledInFusion": True,
                "hgt": 425.846145702526,
                "identifier": 3,
                "incoming": "cpu",
                "lat": 50.0882512280772,
                "lon": 14.245470015132756,
                "mlat_system": None,
                "name": "MLAT 3",
                "probability": 1,
                "redundancy": None,
                "rms_confirmed": "{'MLAT-1': None, 'MLAT-2': None, 'MLAT-3': None, 'MLAT-4': None}",
                "sensitivity": "0.5",
                "tileIndex": 4945,
                "timeJammingSince": "{'MLAT-1': 35.0, 'MLAT-2': 35.0, 'MLAT-3': 35.0, 'MLAT-4': 35.0}",
                "typ": "MLAT System"
            },
            {
                "backup": None,
                "color": "green",
                "enabledInFusion": False,
                "hgt": 4000,
                "identifier": 4,
                "incoming": None,
                "lat": 49.74375,
                "lon": 15.338639,
                "mlat_system": None,
                "name": "Stred CR",
                "probability": None,
                "rms_confirmed": "None",
                "sensitivity": 0.7,
                "tileIndex": None,
                "timeJammingSince": "None",
                "typ": "Airplane"
            },
            {
                "backup": None,
                "color": "green",
                "enabledInFusion": False,
                "hgt": 4000,
                "identifier": 5,
                "incoming": None,
                "lat": 49.9,
                "lon": 15.9,
                "mlat_system": None,
                "name": "Random Marker",
                "probability": None,
                "rms_confirmed": "None",
                "sensitivity": 0.7,
                "tileIndex": None,
                "timeJammingSince": "None",
                "typ": "Vehicle"
            },
            {
                "backup": None,
                "color": "green",
                "enabledInFusion": False,
                "hgt": 4000,
                "identifier": 6,
                "incoming": None,
                "lat": 50.12,
                "lon": 14.15,
                "mlat_system": None,
                "name": "Praha",
                "probability": None,
                "rms_confirmed": "None",
                "sensitivity": 0.7,
                "tileIndex": 5236,
                "timeJammingSince": "None",
                "typ": "RADAR"
            },
            {
                "backup": None,
                "color": "green",
                "enabledInFusion": False,
                "hgt": 4000,
                "identifier": 7,
                "incoming": None,
                "lat": 50.22,
                "lon": 14.25,
                "mlat_system": None,
                "name": "Praha 2",
                "probability": None,
                "rms_confirmed": "None",
                "sensitivity": 0.7,
                "tileIndex": 6145,
                "timeJammingSince": "None",
                "typ": "ADS-B System"
            },
            {
                "backup": None,
                "color": "green",
                "enabledInFusion": False,
                "hgt": 4000,
                "identifier": 8,
                "incoming": None,
                "lat": 50.12,
                "lon": 14.05,
                "mlat_system": None,
                "name": "Praha 3",
                "probability": None,
                "rms_confirmed": "None",
                "sensitivity": 0.7,
                "tileIndex": 5227,
                "timeJammingSince": "None",
                "typ": "MLAT System"
            },
            {
                "backup": None,
                "color": "green",
                "enabledInFusion": False,
                "hgt": 4000,
                "identifier": 9,
                "incoming": None,
                "lat": 50.124209985455565,
                "lon": 14.301380914837464,
                "mlat_system": None,
                "name": "9_Airplane 1",
                "probability": None,
                "rms_confirmed": "None",
                "sensitivity": 0.7,
                "tileIndex": 5250,
                "timeJammingSince": "None",
                "typ": "Data Processing System"
            },
            {
                "backup": None,
                "color": "green",
                "enabledInFusion": False,
                "hgt": 4000,
                "identifier": 10,
                "incoming": None,
                "lat": 50.0882512280772,
                "lon": 14.30135998486724,
                "mlat_system": None,
                "name": "10_Airplane 2",
                "probability": None,
                "rms_confirmed": "None",
                "sensitivity": 0.7,
                "tileIndex": 4950,
                "timeJammingSince": "None",
                "typ": "Airplane"
            },
            {
                "backup": None,
                "color": "green",
                "enabledInFusion": False,
                "hgt": 4000,
                "identifier": 12,
                "incoming": None,
                "lat": 50.1,
                "lon": 14.28,
                "mlat_system": None,
                "name": "13_Airplane 1",
                "probability": None,
                "rms_confirmed": "None",
                "sensitivity": 0.7,
                "tileIndex": 5048,
                "timeJammingSince": "None",
                "typ": "Data Processing System"
            },
            {
                "backup": None,
                "color": "green",
                "enabledInFusion": False,
                "hgt": 4000,
                "identifier": 13,
                "incoming": None,
                "lat": 50.57113745662007,
                "lon": 13.837015281317054,
                "mlat_system": None,
                "name": "Top Left",
                "probability": None,
                "rms_confirmed": "None",
                "sensitivity": 0.7,
                "tileIndex": 9508,
                "timeJammingSince": "None",
                "typ": "Data Processing System"
            },
            {
                "backup": None,
                "color": "green",
                "enabledInFusion": False,
                "hgt": 4000,
                "identifier": 14,
                "incoming": None,
                "lat": 49.59554112809707,
                "lon": 14.787169519514498,
                "mlat_system": None,
                "name": "Bottom Right",
                "probability": None,
                "rms_confirmed": "None",
                "sensitivity": 0.7,
                "tileIndex": 394,
                "timeJammingSince": "None",
                "typ": "Data Processing System"
            },
            {
                "backup": None,
                "color": "green",
                "enabledInFusion": False,
                "hgt": 4000,
                "identifier": 15,
                "incoming": None,
                "lat": 49.49554112809707,
                "lon": 14.687169519514498,
                "mlat_system": None,
                "name": "16_Bottom Right",
                "probability": None,
                "rms_confirmed": "None",
                "sensitivity": 0.7,
                "tileIndex": "Praha 3",
                "timeJammingSince": "None",
                "typ": "MLAT Antenna"
            },
            {
                "backup": None,
                "color": "green",
                "enabledInFusion": True,
                "hgt": 4000,
                "identifier": 16,
                "incoming": None,
                "lat": 49,
                "lon": 14,
                "mlat_system": None,
                "name": "new onee",
                "probability": None,
                "rms_confirmed": "None",
                "sensitivity": "0.5",
                "tileIndex": None,
                "timeJammingSince": "None",
                "typ": "Airplane"
            },
            {
                "backup": None,
                "color": "green",
                "enabledInFusion": False,
                "hgt": 4000,
                "identifier": 17,
                "incoming": None,
                "lat": 49.6,
                "lon": 14.8,
                "mlat_system": None,
                "name": "second one",
                "probability": None,
                "rms_confirmed": "{'Letadlo-1': None, 'Letadlo-2': None, 'Letadlo-3': None, 'Letadlo-4': None, 'Letadlo-5': None}",
                "sensitivity": 0.3,
                "tileIndex": 396,
                "timeJammingSince": "{'Letadlo-1': None, 'Letadlo-2': None, 'Letadlo-3': None, 'Letadlo-4': None, 'Letadlo-5': None}",
                "typ": "RADAR"
            },
            {
                "name": "second one",
                "typ": "RADAR",
                "color": "green",
                "lat": 49.6,
                "lon": 14.8,
                "hgt": 4000,
                "sensitivity": 0.3,
                "incoming": None,
                "backup": None,
                "enabledInFusion": False,
                "identifier": 17,
                "tileIndex": 396,
                "timeJammingSince": "None",
                "probability": None,
                "rms_confirmed": "None",
                "mlat_system": None
            }]
        dash_markers        = [
            {
                "props":
                {
                    "children":
                    [
                        {
                            "props":
                            {
                                "children":
                                [
                                    {
                                        "props":
                                        {
                                            "children":
                                            [
                                                {
                                                    "props":
                                                    {
                                                        "children": "Airplane 1 / Airplane"
                                                    },
                                                    "type": "B",
                                                    "namespace": "dash_html_components"
                                                },
                                                {
                                                    "props":
                                                    {
                                                        "children": None
                                                    },
                                                    "type": "Br",
                                                    "namespace": "dash_html_components"
                                                },
                                                "Intensity:   0.04231",
                                                {
                                                    "props":
                                                    {
                                                        "children": None
                                                    },
                                                    "type": "Br",
                                                    "namespace": "dash_html_components"
                                                },
                                                "Sensitivity: 0.70000",
                                                {
                                                    "props":
                                                    {
                                                        "children": None
                                                    },
                                                    "type": "Br",
                                                    "namespace": "dash_html_components"
                                                },
                                                "Probability: 0.77051",
                                                {
                                                    "props":
                                                    {
                                                        "children": None
                                                    },
                                                    "type": "Br",
                                                    "namespace": "dash_html_components"
                                                },
                                                {
                                                    "props":
                                                    {
                                                        "children": None
                                                    },
                                                    "type": "Br",
                                                    "namespace": "dash_html_components"
                                                },
                                                {
                                                    "props":
                                                    {
                                                        "children": "Time Jammed"
                                                    },
                                                    "type": "B",
                                                    "namespace": "dash_html_components"
                                                },
                                                {
                                                    "props":
                                                    {
                                                        "children":
                                                        [
                                                            {
                                                                "props":
                                                                {
                                                                    "children":
                                                                    [
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children": "RMs",
                                                                                "style":
                                                                                {
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Th",
                                                                            "namespace": "dash_html_components"
                                                                        },
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children": "P",
                                                                                "style":
                                                                                {
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Th",
                                                                            "namespace": "dash_html_components"
                                                                        },
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children": "Time",
                                                                                "style":
                                                                                {
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Th",
                                                                            "namespace": "dash_html_components"
                                                                        }
                                                                    ]
                                                                },
                                                                "type": "Tr",
                                                                "namespace": "dash_html_components"
                                                            },
                                                            {
                                                                "props":
                                                                {
                                                                    "children":
                                                                    [
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children": "Letadlo-1"
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        },
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children":
                                                                                [
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": "0.771",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "red"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    },
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": " / 0.4",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "black"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    }
                                                                                ],
                                                                                "style":
                                                                                {
                                                                                    "padding-left": "0.5em",
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        },
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children":
                                                                                [
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": "0:00:00",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "black"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    },
                                                                                    " / -:--:--"
                                                                                ],
                                                                                "style":
                                                                                {
                                                                                    "padding-left": "0.5em",
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        }
                                                                    ]
                                                                },
                                                                "type": "Tr",
                                                                "namespace": "dash_html_components"
                                                            },
                                                            {
                                                                "props":
                                                                {
                                                                    "children":
                                                                    [
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children": "Letadlo-2"
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        },
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children":
                                                                                [
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": "0.771",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "red"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    },
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": " / 0.6",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "black"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    }
                                                                                ],
                                                                                "style":
                                                                                {
                                                                                    "padding-left": "0.5em",
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        },
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children":
                                                                                [
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": "0:00:00",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "black"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    },
                                                                                    " / -:--:--"
                                                                                ],
                                                                                "style":
                                                                                {
                                                                                    "padding-left": "0.5em",
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        }
                                                                    ]
                                                                },
                                                                "type": "Tr",
                                                                "namespace": "dash_html_components"
                                                            },
                                                            {
                                                                "props":
                                                                {
                                                                    "children":
                                                                    [
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children": "Letadlo-3"
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        },
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children":
                                                                                [
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": "0.771",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "red"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    },
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": " / 0.6",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "black"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    }
                                                                                ],
                                                                                "style":
                                                                                {
                                                                                    "padding-left": "0.5em",
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        },
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children":
                                                                                [
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": "0:00:00",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "black"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    },
                                                                                    " / -:--:--"
                                                                                ],
                                                                                "style":
                                                                                {
                                                                                    "padding-left": "0.5em",
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        }
                                                                    ]
                                                                },
                                                                "type": "Tr",
                                                                "namespace": "dash_html_components"
                                                            },
                                                            {
                                                                "props":
                                                                {
                                                                    "children":
                                                                    [
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children": "Letadlo-4"
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        },
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children":
                                                                                [
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": "0.771",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "green"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    },
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": " / 0.9",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "black"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    }
                                                                                ],
                                                                                "style":
                                                                                {
                                                                                    "padding-left": "0.5em",
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        },
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children":
                                                                                [
                                                                                    "-:--:--",
                                                                                    " / -:--:--"
                                                                                ],
                                                                                "style":
                                                                                {
                                                                                    "padding-left": "0.5em",
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        }
                                                                    ]
                                                                },
                                                                "type": "Tr",
                                                                "namespace": "dash_html_components"
                                                            },
                                                            {
                                                                "props":
                                                                {
                                                                    "children":
                                                                    [
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children": "Letadlo-5"
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        },
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children":
                                                                                [
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": "0.771",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "green"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    },
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": " / 0.9",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "black"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    }
                                                                                ],
                                                                                "style":
                                                                                {
                                                                                    "padding-left": "0.5em",
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        },
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children":
                                                                                [
                                                                                    "-:--:--",
                                                                                    " / -:--:--"
                                                                                ],
                                                                                "style":
                                                                                {
                                                                                    "padding-left": "0.5em",
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        }
                                                                    ]
                                                                },
                                                                "type": "Tr",
                                                                "namespace": "dash_html_components"
                                                            }
                                                        ],
                                                        "style":
                                                        {
                                                            "font-size": "inherit"
                                                        }
                                                    },
                                                    "type": "Table",
                                                    "namespace": "dash_html_components"
                                                }
                                            ],
                                            "id":
                                            {
                                                "type": "marker_intensity",
                                                "index": 0
                                            }
                                        },
                                        "type": "Div",
                                        "namespace": "dash_html_components"
                                    }
                                ]
                            },
                            "type": "Popup",
                            "namespace": "dash_leaflet"
                        },
                        {
                            "props":
                            {
                                "children": None,
                                "id": "marker_0",
                                "style":
                                {
                                    "display": "None"
                                }
                            },
                            "type": "Div",
                            "namespace": "dash_html_components"
                        }
                    ],
                    "icon":
                    {
                        "iconUrl": "assets/icons/marker_red_Airplane.png",
                        "iconSize":
                        [
                            40,
                            40
                        ],
                        "shadowSize":
                        [
                            50,
                            64
                        ],
                        "iconAnchor":
                        [
                            20,
                            40
                        ],
                        "shadowAnchor":
                        [
                            4,
                            62
                        ],
                        "popupAnchor":
                        [
                            0,
                            -50
                        ],
                        "tooltipAnchor":
                        [
                            20,
                            -20
                        ]
                    },
                    "position":
                    [
                        50.124209985455565,
                        14.301380914837464
                    ]
                },
                "type": "Marker",
                "namespace": "dash_leaflet"
            },
            {
                "props":
                {
                    "children":
                    [
                        {
                            "props":
                            {
                                "children":
                                [
                                    {
                                        "props":
                                        {
                                            "children":
                                            [
                                                {
                                                    "props":
                                                    {
                                                        "children": "Airplane 2 / MLAT Antenna"
                                                    },
                                                    "type": "B",
                                                    "namespace": "dash_html_components"
                                                },
                                                {
                                                    "props":
                                                    {
                                                        "children": None
                                                    },
                                                    "type": "Br",
                                                    "namespace": "dash_html_components"
                                                },
                                                "Intensity:   0.04231",
                                                {
                                                    "props":
                                                    {
                                                        "children": None
                                                    },
                                                    "type": "Br",
                                                    "namespace": "dash_html_components"
                                                },
                                                "Sensitivity: 0.70000",
                                                {
                                                    "props":
                                                    {
                                                        "children": None
                                                    },
                                                    "type": "Br",
                                                    "namespace": "dash_html_components"
                                                },
                                                "Probability: 0.94744",
                                                {
                                                    "props":
                                                    {
                                                        "children": None
                                                    },
                                                    "type": "Br",
                                                    "namespace": "dash_html_components"
                                                },
                                                {
                                                    "props":
                                                    {
                                                        "children": None
                                                    },
                                                    "type": "Br",
                                                    "namespace": "dash_html_components"
                                                },
                                                {
                                                    "props":
                                                    {
                                                        "children": "Time Jammed"
                                                    },
                                                    "type": "B",
                                                    "namespace": "dash_html_components"
                                                },
                                                {
                                                    "props":
                                                    {
                                                        "children":
                                                        [
                                                            {
                                                                "props":
                                                                {
                                                                    "children":
                                                                    [
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children": "RMs",
                                                                                "style":
                                                                                {
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Th",
                                                                            "namespace": "dash_html_components"
                                                                        },
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children": "P",
                                                                                "style":
                                                                                {
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Th",
                                                                            "namespace": "dash_html_components"
                                                                        },
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children": "Time",
                                                                                "style":
                                                                                {
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Th",
                                                                            "namespace": "dash_html_components"
                                                                        }
                                                                    ]
                                                                },
                                                                "type": "Tr",
                                                                "namespace": "dash_html_components"
                                                            },
                                                            {
                                                                "props":
                                                                {
                                                                    "children":
                                                                    [
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children": "MLAT-Ant-1"
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        },
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children":
                                                                                [
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": "0.947",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "red"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    },
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": " / 0.3",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "black"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    }
                                                                                ],
                                                                                "style":
                                                                                {
                                                                                    "padding-left": "0.5em",
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        },
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children":
                                                                                [
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": "0:00:00",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "black"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    },
                                                                                    " / -:--:--"
                                                                                ],
                                                                                "style":
                                                                                {
                                                                                    "padding-left": "0.5em",
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        }
                                                                    ]
                                                                },
                                                                "type": "Tr",
                                                                "namespace": "dash_html_components"
                                                            }
                                                        ],
                                                        "style":
                                                        {
                                                            "font-size": "inherit"
                                                        }
                                                    },
                                                    "type": "Table",
                                                    "namespace": "dash_html_components"
                                                }
                                            ],
                                            "id":
                                            {
                                                "type": "marker_intensity",
                                                "index": 1
                                            }
                                        },
                                        "type": "Div",
                                        "namespace": "dash_html_components"
                                    }
                                ]
                            },
                            "type": "Popup",
                            "namespace": "dash_leaflet"
                        },
                        {
                            "props":
                            {
                                "children": None,
                                "id": "marker_1",
                                "style":
                                {
                                    "display": "None"
                                }
                            },
                            "type": "Div",
                            "namespace": "dash_html_components"
                        }
                    ],
                    "icon":
                    {
                        "iconUrl": "assets/icons/marker_red_MLAT Antenna.png",
                        "iconSize":
                        [
                            40,
                            40
                        ],
                        "shadowSize":
                        [
                            50,
                            64
                        ],
                        "iconAnchor":
                        [
                            20,
                            40
                        ],
                        "shadowAnchor":
                        [
                            4,
                            62
                        ],
                        "popupAnchor":
                        [
                            0,
                            -50
                        ],
                        "tooltipAnchor":
                        [
                            20,
                            -20
                        ]
                    },
                    "position":
                    [
                        50.0882512280772,
                        14.30135998486724
                    ]
                },
                "type": "Marker",
                "namespace": "dash_leaflet"
            },
            {
                "props":
                {
                    "children":
                    [
                        {
                            "props":
                            {
                                "children":
                                [
                                    {
                                        "props":
                                        {
                                            "children":
                                            [
                                                {
                                                    "props":
                                                    {
                                                        "children": "Radar 1 / ADS-B"
                                                    },
                                                    "type": "B",
                                                    "namespace": "dash_html_components"
                                                },
                                                {
                                                    "props":
                                                    {
                                                        "children": None
                                                    },
                                                    "type": "Br",
                                                    "namespace": "dash_html_components"
                                                },
                                                "Intensity:   0.00000",
                                                {
                                                    "props":
                                                    {
                                                        "children": None
                                                    },
                                                    "type": "Br",
                                                    "namespace": "dash_html_components"
                                                },
                                                "Sensitivity: 0.70000",
                                                {
                                                    "props":
                                                    {
                                                        "children": None
                                                    },
                                                    "type": "Br",
                                                    "namespace": "dash_html_components"
                                                },
                                                "Probability: 0.74359",
                                                {
                                                    "props":
                                                    {
                                                        "children": None
                                                    },
                                                    "type": "Br",
                                                    "namespace": "dash_html_components"
                                                },
                                                {
                                                    "props":
                                                    {
                                                        "children": None
                                                    },
                                                    "type": "Br",
                                                    "namespace": "dash_html_components"
                                                },
                                                {
                                                    "props":
                                                    {
                                                        "children": "Time Jammed"
                                                    },
                                                    "type": "B",
                                                    "namespace": "dash_html_components"
                                                },
                                                {
                                                    "props":
                                                    {
                                                        "children":
                                                        [
                                                            {
                                                                "props":
                                                                {
                                                                    "children":
                                                                    [
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children": "RMs",
                                                                                "style":
                                                                                {
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Th",
                                                                            "namespace": "dash_html_components"
                                                                        },
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children": "P",
                                                                                "style":
                                                                                {
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Th",
                                                                            "namespace": "dash_html_components"
                                                                        },
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children": "Time",
                                                                                "style":
                                                                                {
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Th",
                                                                            "namespace": "dash_html_components"
                                                                        }
                                                                    ]
                                                                },
                                                                "type": "Tr",
                                                                "namespace": "dash_html_components"
                                                            },
                                                            {
                                                                "props":
                                                                {
                                                                    "children":
                                                                    [
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children": "ADS-B-1"
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        },
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children":
                                                                                [
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": "0.744",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "green"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    },
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": " / 0.9",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "black"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    }
                                                                                ],
                                                                                "style":
                                                                                {
                                                                                    "padding-left": "0.5em",
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        },
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children":
                                                                                [
                                                                                    "-:--:--",
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": " / 0:30:00",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "black"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    }
                                                                                ],
                                                                                "style":
                                                                                {
                                                                                    "padding-left": "0.5em",
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        }
                                                                    ]
                                                                },
                                                                "type": "Tr",
                                                                "namespace": "dash_html_components"
                                                            },
                                                            {
                                                                "props":
                                                                {
                                                                    "children":
                                                                    [
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children": "ADS-B-2"
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        },
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children":
                                                                                [
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": "0.744",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "green"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    },
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": " / 0.9",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "black"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    }
                                                                                ],
                                                                                "style":
                                                                                {
                                                                                    "padding-left": "0.5em",
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        },
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children":
                                                                                [
                                                                                    "-:--:--",
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": " / 0:40:00",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "black"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    }
                                                                                ],
                                                                                "style":
                                                                                {
                                                                                    "padding-left": "0.5em",
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        }
                                                                    ]
                                                                },
                                                                "type": "Tr",
                                                                "namespace": "dash_html_components"
                                                            },
                                                            {
                                                                "props":
                                                                {
                                                                    "children":
                                                                    [
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children": "ADS-B-3"
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        },
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children":
                                                                                [
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": "0.744",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "green"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    },
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": " / 0.9",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "black"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    }
                                                                                ],
                                                                                "style":
                                                                                {
                                                                                    "padding-left": "0.5em",
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        },
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children":
                                                                                [
                                                                                    "-:--:--",
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": " / 0:50:00",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "black"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    }
                                                                                ],
                                                                                "style":
                                                                                {
                                                                                    "padding-left": "0.5em",
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        }
                                                                    ]
                                                                },
                                                                "type": "Tr",
                                                                "namespace": "dash_html_components"
                                                            }
                                                        ],
                                                        "style":
                                                        {
                                                            "font-size": "inherit"
                                                        }
                                                    },
                                                    "type": "Table",
                                                    "namespace": "dash_html_components"
                                                }
                                            ],
                                            "id":
                                            {
                                                "type": "marker_intensity",
                                                "index": 2
                                            }
                                        },
                                        "type": "Div",
                                        "namespace": "dash_html_components"
                                    }
                                ]
                            },
                            "type": "Popup",
                            "namespace": "dash_leaflet"
                        },
                        {
                            "props":
                            {
                                "children": None,
                                "id": "marker_2",
                                "style":
                                {
                                    "display": "None"
                                }
                            },
                            "type": "Div",
                            "namespace": "dash_html_components"
                        }
                    ],
                    "icon":
                    {
                        "iconUrl": "assets/icons/marker_green_ADS-B.png",
                        "iconSize":
                        [
                            40,
                            40
                        ],
                        "shadowSize":
                        [
                            50,
                            64
                        ],
                        "iconAnchor":
                        [
                            20,
                            40
                        ],
                        "shadowAnchor":
                        [
                            4,
                            62
                        ],
                        "popupAnchor":
                        [
                            0,
                            -50
                        ],
                        "tooltipAnchor":
                        [
                            20,
                            -20
                        ]
                    },
                    "position":
                    [
                        50.12420998545556,
                        14.245449085162532
                    ]
                },
                "type": "Marker",
                "namespace": "dash_leaflet"
            },
            {
                "props":
                {
                    "children":
                    [
                        {
                            "props":
                            {
                                "children":
                                [
                                    {
                                        "props":
                                        {
                                            "children":
                                            [
                                                {
                                                    "props":
                                                    {
                                                        "children": "MLAT 3 / MLAT"
                                                    },
                                                    "type": "B",
                                                    "namespace": "dash_html_components"
                                                },
                                                {
                                                    "props":
                                                    {
                                                        "children": None
                                                    },
                                                    "type": "Br",
                                                    "namespace": "dash_html_components"
                                                },
                                                "Intensity:   0.03333",
                                                {
                                                    "props":
                                                    {
                                                        "children": None
                                                    },
                                                    "type": "Br",
                                                    "namespace": "dash_html_components"
                                                },
                                                "Sensitivity: 0.50000",
                                                {
                                                    "props":
                                                    {
                                                        "children": None
                                                    },
                                                    "type": "Br",
                                                    "namespace": "dash_html_components"
                                                },
                                                "Probability: 1.00000",
                                                {
                                                    "props":
                                                    {
                                                        "children": None
                                                    },
                                                    "type": "Br",
                                                    "namespace": "dash_html_components"
                                                },
                                                {
                                                    "props":
                                                    {
                                                        "children": None
                                                    },
                                                    "type": "Br",
                                                    "namespace": "dash_html_components"
                                                },
                                                {
                                                    "props":
                                                    {
                                                        "children": "Time Jammed"
                                                    },
                                                    "type": "B",
                                                    "namespace": "dash_html_components"
                                                },
                                                {
                                                    "props":
                                                    {
                                                        "children":
                                                        [
                                                            {
                                                                "props":
                                                                {
                                                                    "children":
                                                                    [
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children": "RMs",
                                                                                "style":
                                                                                {
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Th",
                                                                            "namespace": "dash_html_components"
                                                                        },
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children": "P",
                                                                                "style":
                                                                                {
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Th",
                                                                            "namespace": "dash_html_components"
                                                                        },
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children": "Time",
                                                                                "style":
                                                                                {
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Th",
                                                                            "namespace": "dash_html_components"
                                                                        }
                                                                    ]
                                                                },
                                                                "type": "Tr",
                                                                "namespace": "dash_html_components"
                                                            },
                                                            {
                                                                "props":
                                                                {
                                                                    "children":
                                                                    [
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children": "MLAT-1"
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        },
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children":
                                                                                [
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": "1.000",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "red"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    },
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": " / 0.9",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "black"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    }
                                                                                ],
                                                                                "style":
                                                                                {
                                                                                    "padding-left": "0.5em",
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        },
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children":
                                                                                [
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": "0:00:00",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "green"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    },
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": " / 0:01:00",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "black"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    }
                                                                                ],
                                                                                "style":
                                                                                {
                                                                                    "padding-left": "0.5em",
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        }
                                                                    ]
                                                                },
                                                                "type": "Tr",
                                                                "namespace": "dash_html_components"
                                                            },
                                                            {
                                                                "props":
                                                                {
                                                                    "children":
                                                                    [
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children": "MLAT-2"
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        },
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children":
                                                                                [
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": "1.000",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "red"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    },
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": " / 0.9",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "black"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    }
                                                                                ],
                                                                                "style":
                                                                                {
                                                                                    "padding-left": "0.5em",
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        },
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children":
                                                                                [
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": "0:00:00",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "green"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    },
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": " / 0:30:00",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "black"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    }
                                                                                ],
                                                                                "style":
                                                                                {
                                                                                    "padding-left": "0.5em",
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        }
                                                                    ]
                                                                },
                                                                "type": "Tr",
                                                                "namespace": "dash_html_components"
                                                            },
                                                            {
                                                                "props":
                                                                {
                                                                    "children":
                                                                    [
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children": "MLAT-3"
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        },
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children":
                                                                                [
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": "1.000",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "red"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    },
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": " / 0.9",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "black"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    }
                                                                                ],
                                                                                "style":
                                                                                {
                                                                                    "padding-left": "0.5em",
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        },
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children":
                                                                                [
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": "0:00:00",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "green"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    },
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": " / 0:30:00",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "black"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    }
                                                                                ],
                                                                                "style":
                                                                                {
                                                                                    "padding-left": "0.5em",
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        }
                                                                    ]
                                                                },
                                                                "type": "Tr",
                                                                "namespace": "dash_html_components"
                                                            },
                                                            {
                                                                "props":
                                                                {
                                                                    "children":
                                                                    [
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children": "MLAT-4"
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        },
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children":
                                                                                [
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": "1.000",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "red"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    },
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": " / 0.9",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "black"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    }
                                                                                ],
                                                                                "style":
                                                                                {
                                                                                    "padding-left": "0.5em",
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        },
                                                                        {
                                                                            "props":
                                                                            {
                                                                                "children":
                                                                                [
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": "0:00:00",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "green"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    },
                                                                                    {
                                                                                        "props":
                                                                                        {
                                                                                            "children": " / 0:30:00",
                                                                                            "style":
                                                                                            {
                                                                                                "color": "black"
                                                                                            }
                                                                                        },
                                                                                        "type": "Span",
                                                                                        "namespace": "dash_html_components"
                                                                                    }
                                                                                ],
                                                                                "style":
                                                                                {
                                                                                    "padding-left": "0.5em",
                                                                                    "text-align": "center"
                                                                                }
                                                                            },
                                                                            "type": "Td",
                                                                            "namespace": "dash_html_components"
                                                                        }
                                                                    ]
                                                                },
                                                                "type": "Tr",
                                                                "namespace": "dash_html_components"
                                                            }
                                                        ],
                                                        "style":
                                                        {
                                                            "font-size": "inherit"
                                                        }
                                                    },
                                                    "type": "Table",
                                                    "namespace": "dash_html_components"
                                                }
                                            ],
                                            "id":
                                            {
                                                "type": "marker_intensity",
                                                "index": 3
                                            }
                                        },
                                        "type": "Div",
                                        "namespace": "dash_html_components"
                                    }
                                ]
                            },
                            "type": "Popup",
                            "namespace": "dash_leaflet"
                        },
                        {
                            "props":
                            {
                                "children": None,
                                "id": "marker_3",
                                "style":
                                {
                                    "display": "None"
                                }
                            },
                            "type": "Div",
                            "namespace": "dash_html_components"
                        }
                    ],
                    "icon":
                    {
                        "iconUrl": "assets/icons/marker_green_MLAT.png",
                        "iconSize":
                        [
                            40,
                            40
                        ],
                        "shadowSize":
                        [
                            50,
                            64
                        ],
                        "iconAnchor":
                        [
                            20,
                            40
                        ],
                        "shadowAnchor":
                        [
                            4,
                            62
                        ],
                        "popupAnchor":
                        [
                            0,
                            -50
                        ],
                        "tooltipAnchor":
                        [
                            20,
                            -20
                        ]
                    },
                    "position":
                    [
                        50.0882512280772,
                        14.245470015132756
                    ]
                },
                "type": "Marker",
                "namespace": "dash_leaflet"
            },
            {
                "props":
                {
                    "children":
                    [
                        {
                            "props":
                            {
                                "children":
                                [
                                    {
                                        "props":
                                        {
                                            "children":
                                            [
                                                {
                                                    "props":
                                                    {
                                                        "children": "new onee / Airplane"
                                                    },
                                                    "type": "B",
                                                    "namespace": "dash_html_components"
                                                },
                                                {
                                                    "props":
                                                    {
                                                        "children": None
                                                    },
                                                    "type": "Br",
                                                    "namespace": "dash_html_components"
                                                },
                                                "No intensity",
                                                {
                                                    "props":
                                                    {
                                                        "children": None
                                                    },
                                                    "type": "Br",
                                                    "namespace": "dash_html_components"
                                                },
                                                "No sensitivity",
                                                {
                                                    "props":
                                                    {
                                                        "children": None
                                                    },
                                                    "type": "Br",
                                                    "namespace": "dash_html_components"
                                                },
                                                "No probability",
                                                {
                                                    "props":
                                                    {
                                                        "children":
                                                        [],
                                                        "style":
                                                        {
                                                            "font-size": "inherit"
                                                        }
                                                    },
                                                    "type": "Table",
                                                    "namespace": "dash_html_components"
                                                }
                                            ],
                                            "id":
                                            {
                                                "type": "marker_intensity",
                                                "index": 16
                                            }
                                        },
                                        "type": "Div",
                                        "namespace": "dash_html_components"
                                    }
                                ]
                            },
                            "type": "Popup",
                            "namespace": "dash_leaflet"
                        },
                        {
                            "props":
                            {
                                "children": None,
                                "id": "marker_16",
                                "style":
                                {
                                    "display": "None"
                                }
                            },
                            "type": "Div",
                            "namespace": "dash_html_components"
                        }
                    ],
                    "icon":
                    {
                        "iconUrl": "assets/icons/marker_green_Airplane.png",
                        "iconSize":
                        [
                            40,
                            40
                        ],
                        "shadowSize":
                        [
                            50,
                            64
                        ],
                        "iconAnchor":
                        [
                            20,
                            40
                        ],
                        "shadowAnchor":
                        [
                            4,
                            62
                        ],
                        "popupAnchor":
                        [
                            0,
                            -50
                        ],
                        "tooltipAnchor":
                        [
                            20,
                            -20
                        ]
                    },
                    "position":
                    [
                        49,
                        14
                    ]
                },
                "type": "Marker",
                "namespace": "dash_leaflet"
            }]
        rms_info_table      = [
            {
                "Name": "Airplane 2",
                "RMs": "MLAT Antenna p > 0.3",
                "RM_ID": "MLAT-Ant-1"
            },
            {
                "Name": "Airplane 1",
                "RMs": "Upozornit posádku letadla ‚call sign‘ na výskyt hrozby GNSS rušení. Posádka by měla být připravena na nedostupnost GNSS based landing procedur.",
                "RM_ID": "Letadlo-3"
            },
            {
                "Name": "Airplane 1",
                "RMs": "Upozorni posádku letadla ‚call sign‘ na výskyt hrozby GNSS rušení. Posádka by měla být připravena přejít na alternativní způsob navigace a aplikace definovaných procedur.",
                "RM_ID": "Letadlo-2"
            },
            {
                "Name": "Airplane 1",
                "RMs": "V dané oblasti hrozí výpadek GNSS. Je třeba být připraven podat posádkám potřebnou asistenci.",
                "RM_ID": "Letadlo-1"
            }]
        devices_count       = 18

        # Expected reuslts
        selected_text               = f"Selected rows: {selected_rows}"
        rows_to_keep                = rms_info_table    # Nothing changed in RMs Info Table
        devices_jamming_signal_list = ['Airplane 1', 'Airplane 2', 'Radar 1', 'MLAT 3', 'new onee']     # List of device whic are active / enabled in fusion
        device_count                = 23

        expected_result = (
            f"Selected rows: {selected_rows}",
            dash_markers,
            devices_data,
            devices_data,
            rows_to_keep,
            devices_jamming_signal_list,
            device_count
            )

        r_text, r_dash_markers, r_devices, r_devices, r_rows, r_jam_list, r_dev_count = display_delete_rows(isRendering, selected_rows, rows_to_delete, devices_data, devices_data_colors, dash_markers, rms_info_table, devices_count)

        print(f"r_jam_list: {r_jam_list} | devices_jamming_signal_list: {devices_jamming_signal_list}")

        self.assertTrue(        r_text == selected_text )
        self.assertTrue(r_dash_markers == dash_markers )
        self.assertTrue(     r_devices == devices_data )
        self.assertTrue(        r_rows == rows_to_keep )
        self.assertTrue(    r_jam_list == devices_jamming_signal_list )
        self.assertTrue(   r_dev_count == r_dev_count )


###############################################################################
# Unit tests
if __name__ == '__main__':
    unittest.main()

