import sys
sys.path.append('../Visualiser')

from appEnums  import LimitsEnum, ConfigEnum, ConfigStrings, TabsEnum
from main_dash import app
from utils     import getCallBackContextIndex, convertValueDeg2Rad, prepareVars, prepareDensityVars, prepareDensityVarsSpecViz

from dash import Input, Output, callback_context, dcc, html, ALL, MATCH

import dash_bootstrap_components as dbc
import dash_daq                  as daq
import numpy                     as np
import plotly.express            as px
import plotly.graph_objects      as go


def createToggleSwitch(index, toggle):
    return daq.ToggleSwitch(id={"type": "spec_vis_integrate_toggle", "index": index}, value=toggle, color="green", style={"width":"10vh"})

def createInput(name, index, value=None, disabled=False, limit_min=None, limit_max=None):
    return dcc.Input(type="number", id={"type": name, "index": index}, value=value, disabled=disabled, min=limit_min, max=limit_max)

def createRow(name, v_min, v_max, toggle, probab_min, probab_max, limit_min, limit_max, index, steps, can_be_int):
    # Due to circular import, imported here
    from views.visualisation import createSlider, createRow_SliderValue

    width_slidr = '35vw'
    width_value = '75px'

    return html.Tr([
            html.Td(f"{name}: ", style={'text-align': 'right', 'padding':'0em 0em 2em 0em'}),            
            html.Td(createRow_SliderValue(limit_min), id={"type": "spec_vis_value_min", "index": index},                                                                              style={'width':width_value, 'text-align': 'right', 'padding':'0em 0em 2em 0em'}),
            html.Td(         createSlider(               {"type": "spec_vis_slider",    "index": index}, index,  limit_min, limit_max, limit_min, limit_max, steps, width_slidr, can_be_int), style={'width':width_slidr, 'text-align': 'center'}),
            # html.Td(         createSlider(           {"type": "spec_vis_slider",    "index": index}, index,  limit_min, limit_max, v_min, v_max, steps, width_slidr, can_be_int), style={'width':width_slidr, 'text-align': 'center'}),
            html.Td(createRow_SliderValue(limit_max), id={"type": "spec_vis_value_max", "index": index},                                                                              style={'width':width_value, 'text-align': 'left', 'padding':'0em 0em 2em 0em'}),
            html.Td(createToggleSwitch(index, toggle)),
            html.Td(createInput("spec_vis_probab_mins", index=index, value=probab_min, disabled=toggle)),
            html.Td(createInput("spec_vis_probab_maxs", index=index, value=probab_max, disabled=toggle))
        ])

def getProbability(data):
    ''' Check probability - if present, number of items muset corellate with number of 'integrate_out == false' elements.'''
    ''' To be done. '''
    if not data:
        return None
    if len(data) <= 1:
        return None
    return None


def createMinMaxIntegrate_table(initial_data, limits_init_data):

    try:
        initial_density = initial_data[ConfigEnum.DENSITY .value][2]                    # Specific Visualisation
    except IndexError:                                                                  #   [0] Map, [1] Probability Density, [2] Specific
        initial_density = None                                                          #   Must be redone for more visualisations

    init_empty = limits_init_data == None
    lim_lon_min, lim_lon_max, lim_lon_steps = prepareVars(ConfigStrings.LON  .value, limits_init_data, init_empty, 'Limit.Config.LON')
    lim_lat_min, lim_lat_max, lim_lat_steps = prepareVars(ConfigStrings.LAT  .value, limits_init_data, init_empty, 'Limit.Config.LAT')
    lim_h_min,   lim_h_max,   lim_h_steps   = prepareVars(ConfigStrings.HGT  .value, limits_init_data, init_empty, 'Limit.Config.HGT')
    lim_P_min,   lim_P_max,   lim_P_steps   = prepareVars(ConfigStrings.POWER.value, limits_init_data, init_empty, 'Limit.Config.PWR')

    init_density_empty = initial_density == None
    lon_min, lon_max, lon_togg = prepareDensityVarsSpecViz(ConfigStrings.LON  .value, lim_lon_min, lim_lon_max, initial_density, init_density_empty, 'Config.Limits.LON')
    lat_min, lat_max, lat_togg = prepareDensityVarsSpecViz(ConfigStrings.LAT  .value, lim_lat_min, lim_lat_max, initial_density, init_density_empty, 'Config.Limits.LAT')
    h_min,   h_max,   h_togg   = prepareDensityVarsSpecViz(ConfigStrings.HGT  .value, lim_h_min,   lim_h_max,   initial_density, init_density_empty, 'Config.Limits.HGT')
    P_min,   P_max,   P_togg   = prepareDensityVarsSpecViz(ConfigStrings.POWER.value, lim_P_min,   lim_P_max,   initial_density, init_density_empty, 'Config.Limits.PWR')

    # Probability structure is weird to check
    # initial_probability = getProbability(initial_data[ConfigEnum.PROBABILITY.value])
    lon_prob_min, lon_prob_max = None, None # prepareProbabilityVars(lon_togg, initial_probability)
    lat_prob_min, lat_prob_max = None, None # prepareProbabilityVars(lat_togg, initial_probability)
    h_prob_min,   h_prob_max   = None, None # prepareProbabilityVars(h_togg,   initial_probability)
    P_prob_min,   P_prob_max   = None, None # prepareProbabilityVars(P_togg,   initial_probability)

    return dbc.Row([
                html.Div([
                    html.Br(),
                    html.Table([
                        html.Thead([
                            html.Tr([
                                html.Th(html.H3("")),
                                html.Th(html.H3("Density"),     colSpan=3, style={'text-align': 'center'}),
                                html.Th(html.H3("Probability"), colSpan=3, style={'text-align': 'center'}),
                            ]),
                            html.Tr([
                                html.Th("",          style={'text-align': 'center'}),
                                html.Th("Min",       style={'text-align': 'right'}),
                                html.Th("",          style={'text-align': 'center'}),
                                html.Th("Max",       style={'text-align': 'left'}),
                                html.Th("Integrate", style={'text-align': 'center'}),
                                html.Th("Min",       style={'text-align': 'center'}),
                                html.Th("Max",       style={'text-align': 'center'}),
                            ])
                        ]),
                        html.Tbody([
                            createRow(  f"{LimitsEnum.LATITUDE.string} [{LimitsEnum.LATITUDE.unit}]", lat_min, lat_max, lat_togg, lat_prob_min, lat_prob_max, lim_lat_min, lim_lat_max, LimitsEnum.LATITUDE .value, lim_lat_steps, LimitsEnum.LATITUDE .can_be_int),
                            createRow(f"{LimitsEnum.LONGITUDE.string} [{LimitsEnum.LONGITUDE.unit}]", lon_min, lon_max, lon_togg, lon_prob_min, lon_prob_max, lim_lon_min, lim_lon_max, LimitsEnum.LONGITUDE.value, lim_lon_steps, LimitsEnum.LONGITUDE.can_be_int),
                            createRow(      f"{LimitsEnum.HEIGHT.string} [{LimitsEnum.HEIGHT.unit}]", h_min,   h_max,   h_togg,   h_prob_min,   h_prob_max  , lim_h_min,   lim_h_max,   LimitsEnum.HEIGHT   .value, lim_h_steps  , LimitsEnum.HEIGHT   .can_be_int),
                            createRow(        f"{LimitsEnum.POWER.string} [{LimitsEnum.POWER.unit}]", P_min,   P_max,   P_togg,   P_prob_min,   P_prob_max  , lim_P_min,   lim_P_max,   LimitsEnum.POWER    .value, lim_P_steps  , LimitsEnum.POWER    .can_be_int),

                            html.Tr([html.Td(html.Br())]),     # Empty for space
                            html.Tr([html.Td(html.B("Activate Specific Visualisation: "), style={'text-align': 'center'}, colSpan=7)]),
                            html.Tr([html.Td(daq.ToggleSwitch(id='spec_view_active_toggle', value=False, color="green", style={"width":"15vh", 'text-align': 'center', 'margin': 'auto'}), colSpan=7,  style={"width":"15vh", 'text-align': 'center', 'margin': 'auto'})], style={'text-align': 'center', 'margin': 'auto'})
                        ])
                    ], style={'margin': 'auto'}),
                ]),

                layout_graphs_tab(),
            ])


def create0dTab():
    ''' Tab for unknown dimensions. '''
    return html.Div([html.Br(), html.Span("Cannot represent data with this Integrate setup.")], style={'text-align':'center'})



def create1dTab():
    return dbc.Row(
                dbc.Col([
                    html.Div(["..."], id='spec_view_graph_1d', style={'text-align':'center'})
                ], width=12),
                style={'margin-top':'5em'},
            )


def create2dTab():
    return dbc.Col([
            dcc.Graph(
            id='spec_view_graph_2d',
            figure={
                'data': [{
                    'x': [],
                    'y': [],
                    'type': 'line',
                    'name': '2dgraph'
                }],
                'layout': go.Layout(
                    margin=go.layout.Margin(l=100, r=100, b=100, t=100),
                    xaxis_title="",
                    yaxis_title="pmf [1]",
                )
            },
            style={'height': '50vh'} 
        )
    ], width=12)



def create3dTab():
    figure_histogram = go.Figure(
        data = px.imshow(
            img=[[0],[0]],
            color_continuous_scale='Viridis',
            origin='lower',
            labels={
                'x':"x-axis", "y":"y-axis", "color": "pmf [1]"
            }),
        layout = go.Layout(
            uirevision=True
        )
    )

    return dbc.Col([
        dcc.Graph(
            id='spec_view_graph_3d',
            figure=figure_histogram,
            style={'width': '90vw', 'height': '80vh', 'margin': 'auto', 'background':'white'} 
        )
    ], width=12)



def create4dTab():
    X, Y, Z = np.mgrid[0:1, 0:1, 0:1]
    values  = np.array([0,0,0])

    figure_4d = go.Figure(
        data=go.Surface(
            x=X.flatten(),
            y=Y.flatten(),
            z=values.flatten(),
            colorbar={"title": "pmf [1]"}
        )
    )

    return dbc.Col([
        dcc.Graph(
            id='spec_view_graph_4d',
            figure=figure_4d,
            style={'height': '100vh'}
        )
    ], width=12, style={'width': '80vw', 'height':'90vh', 'background':'white'})


def getFigureLayout(annotation):
    ''' Base for getting figure layout. '''
    return {
        'annotations': annotation
    }

def getFigureLayouWithAnnotation(text):
    ''' Layout with annotation text over figure, so user can be informed about something. '''
    annotation = [
        {
            'text': text,
            'showarrow': False,
            'xref': 'paper',
            'yref': 'paper',
            'x': 0.5,
            'y': 0.5,
            'font': {'size': 20},
            'bgcolor': 'lightgray',
            'bordercolor': 'gray',
            'borderwidth': 2,
            'borderpad': 10
        }
    ]
    return getFigureLayout(annotation)


def getFigureLayouWithoutAnnotation():
    ''' Layout without annotation. '''
    return getFigureLayout([])


def getFigureLayouWithoutAnnotationWithAxis(x_axis, y_axis):
    ''' Layer without annotation, but with axis.'''
    return getFigureLayout([])


def layout_blank_view_tab(initial_data, limits_init_data):
    return  html.Div([
        createMinMaxIntegrate_table(initial_data, limits_init_data)
    ])


def layout_graphs_tab():
    return html.Div([
        html.Div([create1dTab()], id={'type': 'spec_view_tab', 'index': TabsEnum.NUMBER.value}),
        html.Div([create2dTab()], id={'type': 'spec_view_tab', 'index': TabsEnum.GRAPH.value}),
        html.Div([create3dTab()], id={'type': 'spec_view_tab', 'index': TabsEnum.HEAT.value}),
        html.Div([create4dTab()], id={'type': 'spec_view_tab', 'index': TabsEnum.SPACE.value}),
        html.Div([create0dTab()], id={'type': 'spec_view_tab', 'index': TabsEnum.UNKNOWN.value}),
    ])



def getIntegrationLimits(mins, maxs, p_mins, p_maxs, toggles, config_mins, config_maxs, config_steps, shouldConvertUnits):
    ''' Integration Limits JSON structure. '''

    def is_number(variable):
        try:
            float(variable)
            return True
        except (ValueError, TypeError):
            return False
    
    def getProbabs(toggles, data_mins, data_maxs, p1,p2,p3,p4):
        ''' p1-p4 - LimitsEnum '''
        if data_mins == None or data_maxs == None:
            return [], []

        probab_mins, probab_maxs = [], []
        # Issue here is that only Inputs from LimitsEnum which has Toggle set na False can be considered useful.
        #   HOWEVER, from these values, all of them has to numbers to be passed to the JSON Config, otherwise if
        #   just any of those values is not number (empty Input, string or anything else than number), nothing is
        #   passed to the JSON Config Probability attribute.

        # 1) Get not None values - with some actual number of just empty string ''
        for p in [p1, p2, p3, p4]:
            if not toggles[p.value]: 
                if data_mins[p.value] is not None or data_mins[p.value] != '' \
                and data_maxs[p.value] is not None or data_maxs[p.value] != '':
                    probab_mins.append(data_mins[p.value])
                    probab_maxs.append(data_maxs[p.value])
            elif data_mins[p.value] is not None and data_maxs[p.value] is not None:
                pass
            elif data_mins[p.value] is not None or data_maxs[p.value] is not None:
                app.logger.warning(f"Specific visualisation: Probabilities were not correctly set for {p.string} ({data_mins[p.value]}/{type(data_mins[p.value])} and {data_maxs[p.value]}/{type(data_maxs[p.value])})")

        if len(probab_mins) > 0 and len(probab_mins) < toggles.count(False):
            missing_probabs_str = ""
            for p in [p1,p2,p3,p4]:
                if not toggles[p.value]:
                    missing_probabs_str += f"{p.string}:({data_mins[p.value]},{data_maxs[p.value]}); "

            app.logger.warning(f"Specific visualisation: Probabilities were not set correctly - {missing_probabs_str}")
            app.logger.warning(f"Specific visualisation: Probabilities were not set correctly - Skipping the Probabilities part.")
            return [], []

        # 2) Check if all values are numbers, even one NON-number values will be considered no-go and empty lists
        #    Will be returned.
        for i in range(len(probab_mins)):
            # At least one is not number, 'return' empty lists and break the for cycle
            if not is_number(probab_mins[i]) or not is_number(probab_mins[i]):
                probab_mins, probab_maxs = [], []
                break

        return probab_mins, probab_maxs


    # New approach - as all limiting inputs are entered from slider, User cannot enter infinitely small number.
    #       Input value is increased by half step (for mininum limit) and decreased by half step (for maximum limit),
    #       which ensures we are in the center of the 'tile' and no dividing/rounding error can occur.
    for i,step in enumerate(config_steps):
        half_step = ((config_maxs[i] - config_mins[i]) / step) / 2.0
        mins[i] = mins[i] + half_step
        maxs[i] = maxs[i] - half_step


    request_density = {
        "lon": {
            "min":           convertValueDeg2Rad(shouldConvertUnits, mins   [LimitsEnum.LONGITUDE.value]),
            "max":           convertValueDeg2Rad(shouldConvertUnits, maxs   [LimitsEnum.LONGITUDE.value]),
            "integrate_out":                                         toggles[LimitsEnum.LONGITUDE.value]
        },
        "lat": {
            "min":           convertValueDeg2Rad(shouldConvertUnits, mins   [LimitsEnum.LATITUDE.value]),
            "max":           convertValueDeg2Rad(shouldConvertUnits, maxs   [LimitsEnum.LATITUDE.value]),
            "integrate_out":                                         toggles[LimitsEnum.LATITUDE.value]
        },
        "h": {
            "min":           mins   [LimitsEnum.HEIGHT.value],
            "max":           maxs   [LimitsEnum.HEIGHT.value],
            "integrate_out": toggles[LimitsEnum.HEIGHT.value]
        },
        "P": {
            "min":           mins   [LimitsEnum.POWER.value],
            "max":           maxs   [LimitsEnum.POWER.value],
            "integrate_out": toggles[LimitsEnum.POWER.value]
        }
    }

    probab_mins, probab_maxs = getProbabs(toggles, p_mins, p_maxs, LimitsEnum.LONGITUDE, LimitsEnum.LATITUDE, LimitsEnum.HEIGHT, LimitsEnum.POWER)

    # Save probabilities
    if not probab_mins and not probab_maxs:
        request_probability = {}
    else:
        request_probability = {
            "minima": probab_mins,
            "maxima": probab_maxs
        }

    return request_density, request_probability



@app.callback(
    [
        Output({'type': 'spec_vis_probab_mins', 'index': MATCH}, 'disabled'),
        Output({'type': 'spec_vis_probab_maxs', 'index': MATCH}, 'disabled'),
    ],
    Input({'type': 'spec_vis_integrate_toggle', 'index': ALL}, 'value') )
def toggleSwitchAndProbabilityInputs(value):
    index_number = getCallBackContextIndex(callback_context)
    
    if not value[index_number]:
        return False, False
    else:
        return True, True



@app.callback(
    Output({'type': 'spec_vis_value_min', 'index': MATCH}, 'children'),
    Output({'type': 'spec_vis_value_max', 'index': MATCH}, 'children'),
    Input ({'type': 'spec_vis_slider',    'index': MATCH}, 'value'))
def update_sliders_min_max_label_value(values):
    ''' Updates label values in front of / next to the sliders below the map. '''
    # Note: sliders have min/max values, thus @param values is 2-item list

    # Due to circular import, imported here
    from views.visualisation import createRow_SliderValue
    return createRow_SliderValue(values[0]), createRow_SliderValue(values[1])


## NOTE - not that useful as User can be allowed to change properties before activating the specific visualisation
# @app.callback(
#     Output({'type': 'spec_vis_probab_mins',      'index': ALL}, 'disabled', allow_duplicate=True),
#     Output({'type': 'spec_vis_probab_maxs',      'index': ALL}, 'disabled', allow_duplicate=True),
#     Output({'type': 'spec_vis_mins',             'index': ALL}, 'disabled', allow_duplicate=True),
#     Output({'type': 'spec_vis_maxs',             'index': ALL}, 'disabled', allow_duplicate=True),
#     Output({'type': 'spec_vis_integrate_toggle', 'index': ALL}, 'disabled', allow_duplicate=True),
#     Input(          'spec_view_active_toggle',                  'value'),
#     State({'type': 'spec_vis_integrate_toggle',  'index': ALL}, 'value'))
# def toggleActiveAllInputs(value, toggles):
#     ''' (De)activates all inputs based on one Activate Spec Vis toggle.
#         Note: state of Probabilities Inputs is based on their toggle. '''
#     trues  = [ True,  True,  True,  True]
#     falses = [False, False, False, False]

#     if value:
#         return toggles, toggles, falses, falses, falses
#     else:
#         return   trues,   trues, trues, trues, trues












